Struct ReuniteError
pub struct ReuniteError(pub OwnedReadHalf, pub OwnedWriteHalf);Expand description
Error indicating that two halves were not from the same socket, and thus could not be reunited.
Tuple Fields
0: OwnedReadHalf1: OwnedWriteHalfTrait Implementations
impl Debug for ReuniteError
impl Debug for ReuniteError
impl Display for ReuniteError
impl Display for ReuniteError
impl Error for ReuniteError
impl Error for ReuniteError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()